@@ -23,7 +23,7 @@ from circlink.link import LINKS_DIRECTORY, CircuitPythonLink
 
 _TableRowEntry: TypeAlias = Tuple[int, str, bool, pathlib.Path, pathlib.Path, bool, int]
 
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 
 # Prevent running on non-POSIX systems that don't have os.fork()
 if os.name != "posix":
@@ -291,9 +291,9 @@ def restart(link_id: str) -> None:
             sys.exit(1)
 
     link_list = _get_links_list(pattern)
-    if not link_list:
-        print("There are no links in the history")
-        sys.exit(0)
+    if len(link_list) == 1:
+        print("There are no links in the history to restart")
+        sys.exit(1)
 
     for index, link in enumerate(link_list):
         if not index:
